# REL06: How do you monitor workload resources?

## References

- [AWS REL06](https://docs.aws.amazon.com/wellarchitected/latest/framework/rel-06.html)
- [OpenTelemetry](https://opentelemetry.io/)
- [Prometheus](https://prometheus.io/)

## Date

2025-11-27

## Focus Area

Change Management

## Tổng quan

REL06 tập trung vào monitoring workload resources.

## Best Practices

### REL06-BP01: Monitor all components of the workload
Full observability.

### REL06-BP02: Define and calculate metrics
SLIs, SLOs.

### REL06-BP03: Send notifications
Alerting.

### REL06-BP04: Automate responses
Auto-scaling, self-healing.

### REL06-BP05: Conduct reviews regularly
Regular review meetings.

## Checklist

- [ ] All components monitored
- [ ] SLIs/SLOs defined
- [ ] Alerting configured
- [ ] Auto-responses implemented
